@@ -1,9 +1,15 @@
+"""Utils."""
 from astroid.exceptions import InferenceError
 from astroid.bases import YES, Instance
 from astroid.nodes import Class
+import sys
+
+
+PY3 = sys.version_info >= (3, 0)
 
 
 def node_is_subclass(cls, subclass_name):
+    """Checks if cls node has parent with subclass_name."""
     if not isinstance(cls, (Class, Instance)):
         return False
 
@@ -22,4 +28,4 @@ def node_is_subclass(cls, subclass_name):
         except InferenceError:
             pass
 
-    return False
\ No newline at end of file
+    return False
